#!/usr/bin/env python
# -*- coding: utf-8 -*-
#coding=utf-8
# A audio control script.

from ctypes import *               # 导入 ctypes 库中所有模块
import globalPluginHandler
import ui
import os     
import ctypes     

dll = None
path = os.path.dirname(__file__)
dll = ctypes.cdll.LoadLibrary(os.path.join(path, 'AudioControlDll.dll'))
#为了记录当前控制的是什么设备,默认为控制扬声器
nType=0

#准备一些结构体需要的数据，为了获取绘画名称等信息
INFONAME = c_char * 128

class sessionInfo(Structure):
 _fields_ = [
  ("id",c_ulong),
  ("name", INFONAME)
 ]

getProcessName = dll.getProcessName
getProcessName.argtypes = [POINTER(sessionInfo)]

class GlobalPlugin(globalPluginHandler.GlobalPlugin):
 nType = 0

 def script_volumeUp(self, gesture):
  if 0 == self.nType:
   self.vVolumeUp()
  elif 1 == self.nType:
   self.mVolumeUp()
  elif 2 == self.nType:
   self.sVolumeUp()

 def vVolumeUp(self):
  num = dll.getVolume(0)
  num=num+1
  if dll.getMaxVol() >= num:
   dll.setVolume(0, num)
   ui.message(u"%d增大主音量" % num)
  else:
   ui.message(u"100最大主音量")

 def mVolumeUp(self):
  num = dll.getVolume(1)
  num=num+1
  if dll.getMaxVol() >= num:
   dll.setVolume(1, num)
   str = u'%d 增大麦克风音量' % num
   ui.message(str)
  else:
   ui.message(u"100最大麦克风音量")

 def sVolumeUp(self):
  info = sessionInfo()
  info.id = dll.getNowSession()
  num = dll.getVolume(2, info.id)
  num=num+1
  getProcessName(byref(info))
  if dll.getMaxVol() >= num:
   dll.setVolume(2, num, info.id)
   strs = "%d"%num
   ui.message(u"%s增加%s音量" % (strs, info.name.decode('gb2312')))
  else:
   ui.message(u"100最大%s音量" % info.name.decode('gb2312'))

 def script_volumeDown(self, gesture):
  if 0 == self.nType:
   self.vVolumeDown()
  elif 1 == self.nType:
   self.mVolumeDown()
  elif 2 == self.nType:
   self.sVolumeDown()

 def vVolumeDown(self):
  num = dll.getVolume(0)
  num=num-1
  if dll.getMinVol() <= num:
   dll.setVolume(0, num)
   ui.message(u"%d减小主音量" % num)
  else:
   ui.message(u"0最小主音量")

 def mVolumeDown(self):
  num = dll.getVolume(1)
  num=num-1
  if dll.getMinVol() <= num:
   dll.setVolume(1, num)
   ui.message(u'%d减小麦克风音量' % num)
  else:
   ui.message(u"0最小麦克风音量")

 def sVolumeDown(self):
  info = sessionInfo()
  info.id = dll.getNowSession()
  num = dll.getVolume(2, info.id)
  num=num-1
  getProcessName(byref(info))
  if dll.getMinVol() <= num:
   dll.setVolume(2, num, info.id)
   strs = "%d"%num
   ui.message(u"%s减少%s音量" % (strs, info.name.decode('gb2312')))
  else:
   ui.message(u"0最小%s音量" % info.name.decode('gb2312'))

 def mMute(self):
  dll.setMute(1, not dll.getMute(1))
  if dll.getMute(1):
   ui.message(u"关麦")
  else:
   ui.message(u"开麦")

 def vMute(self):
  dll.setMute(0, not dll.getMute(0))
  if dll.getMute(0):
   ui.message(u"静音")
  else:
   ui.message(u"取消静音")

 def sMute(self):
  info = sessionInfo()
  info.id = dll.getNowSession()
  dll.setMute(2, not dll.getMute(2, info.id), info.id)
  if dll.getMute(2, info.id):
   strs = U"关闭"
  else:
   strs = u"打开"
  getProcessName(byref(info))
  ui.message(u"%s%s音量" % (strs, info.name.decode('gb2312')))

 def script_LastSession(self, gesture):
  sessionID = dll.getSessionID()
  if self.nType == 2 and sessionID == 0:
   if self.nType > 0:
    self.nType=self.nType-1
    dll.setSessionID(-1)
  elif self.nType == 1:
   self.nType = 0

  if 0 == self.nType:
   ui.message(u"扬声器音量%d" % dll.getVolume(0))
  elif 1 == self.nType:
   ui.message(u"麦克风音量%d" % dll.getVolume(1))
  elif 2 == self.nType:
   info = sessionInfo()
   info.id = dll.getLastSession()
   getProcessName(byref(info))
   strs = u"%s音量%d" % (info.name.decode('gb2312'), dll.getVolume(2, info.id))
   ui.message(strs)
   
 def script_NextSession(self, gesture):
  if self.nType < 2:
   self.nType = self.nType+1

  if 0 == self.nType:
   ui.message(u"扬声器音量%d" % dll.getVolume(0))
  elif 1 == self.nType:
   ui.message(u"麦克风音量%d" % dll.getVolume(1))
  elif 2 == self.nType:
   info = sessionInfo()
   info.id = dll.getNextSession()
   getProcessName(byref(info))
   strs = u"%s音量%d" % (info.name.decode('gb2312'), dll.getVolume(2, info.id))
   ui.message(strs)

 def script_SetMute(self, gesture):
  if self.nType == 0:#扬声器静音
   self.vMute()
  elif self.nType == 1:#麦克风静音
   self.mMute()
  elif self.nType == 2:#绘画静音
   self.sMute()

 __gestures={
  "kb:Windows+Control+Alt+numpad6":"NextSession",
  "kb:Windows+Control+Alt+numpad4":"LastSession",
  "kb:Windows+Control+Alt+numpad5":"SetMute",
  "kb:Windows+Control+Alt+numpad2":"volumeDown",
  "kb:Windows+control+alt+Numpad8":"volumeUp",
#  "kb:Windows+control+alt+Numpad7":"sVolumeDown",
#  "kb:Windows+control+alt+Numpad9":"sVolumeUp"
 }